@@ -53,11 +53,32 @@
   :group 'xemacsbug
   :type 'string)
 
+(defcustom report-xemacs-bug-extra-headers nil
+  "*An alist of mail-header value pairs for XEamcs bugs.
+
+It takes the format (HEADER . VALUE) where both HEADER and VALUE are
+strings. See `compose-mail'."
+  :group 'xemacsbug
+  :type '(repeat 
+	  (cons (string :tag "Header") 
+		(string :tag "Value"))))
+
 (defcustom report-xemacs-bug-beta-address "xemacs-beta@xemacs.org"
   "*Address of mailing list for XEmacs beta bugs."
   :group 'xemacsbug
   :type 'string)
 
+(defcustom report-xemacs-bug-beta-extra-headers
+  '(("cc" . "ben@xemacs.org"))
+  "*An alist of mail-header value pairs for XEmacs beta bugs.
+
+It takes the format (HEADER . VALUE) where both HEADER and VALUE are
+strings. See `compose-mail'."
+  :group 'xemacsbug
+  :type '(repeat 
+	  (cons (string :tag "Header") 
+		(string :tag "Value"))))
+
 (defvar report-xemacs-bug-orig-text nil
   "The automatically-created initial text of bug report.")
 
@@ -84,10 +105,13 @@ Prompts for bug subject.  Leaves you in a mail buffer."
   ;; the bug subject string is read.
   (interactive (reverse (list (recent-keys) (read-string "Bug Subject: "))))
   (let (user-point)
-    (compose-mail (if (string-match "(beta[0-9]+)" emacs-version)
-		      report-xemacs-bug-beta-address
-		    report-xemacs-bug-address)
-		  topic)
+    (if xemacs-betaname
+	(compose-mail report-xemacs-bug-beta-address
+		      topic
+		      report-xemacs-bug-beta-extra-headers)
+      (compose-mail report-xemacs-bug-address
+		    topic
+		    report-xemacs-bug-extra-headers))
     ;; The rest of this does not execute
     ;; if the user was asked to confirm and said no.
     (goto-char (point-min))
@@ -206,6 +230,7 @@ potentially sensitive data.")))
     (goto-char user-point)))
 
 ;; For backwards compatibility
+;;;###autoload
 (defalias 'report-emacs-bug 'report-xemacs-bug)
 
 (defun report-xemacs-bug-info ()
